(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     94438,       2070]*)
(*NotebookOutlinePosition[     95106,       2093]*)
(*  CellTagsIndexPosition[     95062,       2089]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["In-Vacuum Cabling", "Subtitle"],

Cell["\<\
Temperature rise of a single electrical wire in vacuum assuming the cooling \
is radiation dominated. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Utilities", "Subsection"],

Cell[BoxData[
    \(\($TextStyle = {FontFamily \[Rule] "\<Helvetica\>", 
          FontSize \[Rule] 13};\)\)], "Input"],

Cell[BoxData[
    \(\(plotopt = 
        PlotStyle \[Rule] {{Thickness\ [0.007], \ 
              RGBColor\ [1, 0, 0]}, \n\t\t\t\ \ \ \ {Thickness\ [0.007], \ 
              RGBColor\ [0, 0, 1]}, \n\t\t\t\ \ \ \ {Thickness\ [0.007], \ 
              RGBColor\ [0.1, 0.7, 0.2]}, \n\t\t\t\ \ \ \ {Thickness\ [
                0.007], \ RGBColor\ [0.5, 0.5, 0.2]}};\)\)], "Input"],

Cell[BoxData[
    \(\(textoptsmall = {TextStyle \[Rule] {FontFamily \[Rule] \
"\<Helvetica\>", FontSize \[Rule] 11}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stefan-Boltzmann's law", "Subsection"],

Cell[TextData[{
  "\[Eta]: resistance in \[CapitalOmega]/m\ni: current through wire in A\n\
\[Epsilon]: emissivity of Kapton (around 0.75)\n\[Sigma]: Stefan-Boltzmann \
constant\nd: cable diameter in m\nTamp: ambient temperature in K\nT4 = ",
  Cell[BoxData[
      \(TraditionalForm\`T\^4\)]],
  " with T: cable temperature in K"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Solve[\[Eta]\ i\  == \ \[Epsilon]\ \[Sigma]\ \((T4 - Tamb\^4)\) 
          d\ \[Pi], T4]\), "\[IndentingNewLine]", 
    \(temp = 
      T4\^\(1/4\) /. %\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], "Input"],

Cell[BoxData[
    \({{T4 \[Rule] \(i\ \[Eta] + d\ \[Pi]\ Tamb\^4\ \[Epsilon]\ \
\[Sigma]\)\/\(d\ \[Pi]\ \[Epsilon]\ \[Sigma]\)}}\)], "Output"],

Cell[BoxData[
    \(\((\(i\ \[Eta] + d\ \[Pi]\ Tamb\^4\ \[Epsilon]\ \[Sigma]\)\/\(d\ \
\[Epsilon]\ \[Sigma]\))\)\^\(1/4\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(param = {\[Eta] \[Rule] 0.35, \[Epsilon] \[Rule] 0.75, 
        d \[Rule] 20  Mil, Mil \[Rule] 25.4*^-6, \[Sigma] \[Rule] 5.67*^-8, 
        T0 \[Rule] 273.15, Tamb \[Rule] T0 + 25}\)], "Input"],

Cell[BoxData[
    \({\[Eta] \[Rule] 0.35`, \[Epsilon] \[Rule] 0.75`, d \[Rule] 20\ Mil, 
      Mil \[Rule] 0.0000254`, \[Sigma] \[Rule] 5.67`*^-8, T0 \[Rule] 273.15`, 
      Tamb \[Rule] 25 + T0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Temperature rise as function of wire current", "Subsection"],

Cell["red trace: emissivity of 0.75", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[temp - Tamb //. param, {i, 0, 2}, 
        FrameLabel \[Rule] {"\<current (A)\>", \ "\<Temperature rise (C)\>"}, 
        GridLines \[Rule] Automatic, Frame \[Rule] True, 
        PlotStyle \[Rule] {{Thickness\ [0.007], \ 
              RGBColor\ [1, 0, 0]}, \t\t\t\ \ \ \ {Thickness\ [0.007], \ 
              RGBColor\ [0, 0, 1]}, \t\t\t\ \ \ \ {Thickness\ [0.007], \ 
              RGBColor\ [0.1, 0.7, 0.2]}, \t\t\t\ \ \ \ {Thickness\ [
                0.007], \ RGBColor\ [0.5, 0.5, 0.2]}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.00850217 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.2619 -0.0125 -10.9688 -16.375 ]
[.2619 -0.0125 10.9688 0 ]
[.5 -0.0125 -5.59375 -16.375 ]
[.5 -0.0125 5.59375 0 ]
[.7381 -0.0125 -10.9688 -16.375 ]
[.7381 -0.0125 10.9688 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -32.5313 -32.75 ]
[.5 -0.0125 32.5313 -16.375 ]
[-0.0125 .01472 -11.1875 -8.1875 ]
[-0.0125 .01472 0 8.1875 ]
[-0.0125 .09974 -18.375 -8.1875 ]
[-0.0125 .09974 0 8.1875 ]
[-0.0125 .18476 -18.375 -8.1875 ]
[-0.0125 .18476 0 8.1875 ]
[-0.0125 .26978 -18.375 -8.1875 ]
[-0.0125 .26978 0 8.1875 ]
[-0.0125 .3548 -18.375 -8.1875 ]
[-0.0125 .3548 0 8.1875 ]
[-0.0125 .43982 -18.375 -8.1875 ]
[-0.0125 .43982 0 8.1875 ]
[-0.0125 .52485 -18.375 -8.1875 ]
[-0.0125 .52485 0 8.1875 ]
[-0.0125 .60987 -18.375 -8.1875 ]
[-0.0125 .60987 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -34.75 -61.9063 ]
[-0.01875 .30902 -18.375 61.9063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .09974 m
1 .09974 L
s
0 .18476 m
1 .18476 L
s
0 .26978 m
1 .26978 L
s
0 .3548 m
1 .3548 L
s
0 .43982 m
1 .43982 L
s
0 .52485 m
1 .52485 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -93.5313 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(current) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.750 16.625 moveto
(H) show
111.125 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
119.875 16.625 moveto
(L) show
124.063 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09974 m
.00625 .09974 L
s
gsave
-0.0125 .09974 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .18476 m
.00625 .18476 L
s
gsave
-0.0125 .18476 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .26978 m
.00625 .26978 L
s
gsave
-0.0125 .26978 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .3548 m
.00625 .3548 L
s
gsave
-0.0125 .3548 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .43982 m
.00625 .43982 L
s
gsave
-0.0125 .43982 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .52485 m
.00625 .52485 L
s
gsave
-0.0125 .52485 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .60987 m
.00625 .60987 L
s
gsave
-0.0125 .60987 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03172 m
.00375 .03172 L
s
0 .04872 m
.00375 .04872 L
s
0 .06573 m
.00375 .06573 L
s
0 .08273 m
.00375 .08273 L
s
0 .11674 m
.00375 .11674 L
s
0 .13375 m
.00375 .13375 L
s
0 .15075 m
.00375 .15075 L
s
0 .16775 m
.00375 .16775 L
s
0 .20176 m
.00375 .20176 L
s
0 .21877 m
.00375 .21877 L
s
0 .23577 m
.00375 .23577 L
s
0 .25278 m
.00375 .25278 L
s
0 .28678 m
.00375 .28678 L
s
0 .30379 m
.00375 .30379 L
s
0 .32079 m
.00375 .32079 L
s
0 .3378 m
.00375 .3378 L
s
0 .37181 m
.00375 .37181 L
s
0 .38881 m
.00375 .38881 L
s
0 .40581 m
.00375 .40581 L
s
0 .42282 m
.00375 .42282 L
s
0 .45683 m
.00375 .45683 L
s
0 .47383 m
.00375 .47383 L
s
0 .49084 m
.00375 .49084 L
s
0 .50784 m
.00375 .50784 L
s
0 .54185 m
.00375 .54185 L
s
0 .55885 m
.00375 .55885 L
s
0 .57586 m
.00375 .57586 L
s
0 .59286 m
.00375 .59286 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -149.469 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
122.906 12.1875 translate
90 rotate
-122.906 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temperature) show
140.688 16.625 moveto
(rise) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
165.063 16.625 moveto
(H) show
169.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
178.625 16.625 moveto
(L) show
182.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09974 m
1 .09974 L
s
.99375 .18476 m
1 .18476 L
s
.99375 .26978 m
1 .26978 L
s
.99375 .3548 m
1 .3548 L
s
.99375 .43982 m
1 .43982 L
s
.99375 .52485 m
1 .52485 L
s
.99375 .60987 m
1 .60987 L
s
.125 Mabswid
.99625 .03172 m
1 .03172 L
s
.99625 .04872 m
1 .04872 L
s
.99625 .06573 m
1 .06573 L
s
.99625 .08273 m
1 .08273 L
s
.99625 .11674 m
1 .11674 L
s
.99625 .13375 m
1 .13375 L
s
.99625 .15075 m
1 .15075 L
s
.99625 .16775 m
1 .16775 L
s
.99625 .20176 m
1 .20176 L
s
.99625 .21877 m
1 .21877 L
s
.99625 .23577 m
1 .23577 L
s
.99625 .25278 m
1 .25278 L
s
.99625 .28678 m
1 .28678 L
s
.99625 .30379 m
1 .30379 L
s
.99625 .32079 m
1 .32079 L
s
.99625 .3378 m
1 .3378 L
s
.99625 .37181 m
1 .37181 L
s
.99625 .38881 m
1 .38881 L
s
.99625 .40581 m
1 .40581 L
s
.99625 .42282 m
1 .42282 L
s
.99625 .45683 m
1 .45683 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49084 m
1 .49084 L
s
.99625 .50784 m
1 .50784 L
s
.99625 .54185 m
1 .54185 L
s
.99625 .55885 m
1 .55885 L
s
.99625 .57586 m
1 .57586 L
s
.99625 .59286 m
1 .59286 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .01472 m
.06244 .04763 L
.10458 .08213 L
.14415 .11333 L
.18221 .14233 L
.22272 .17219 L
.26171 .20002 L
.30316 .22869 L
.34309 .25549 L
.3815 .28056 L
.42237 .30652 L
.46172 .33085 L
.49955 .35367 L
.53984 .37739 L
.57861 .39968 L
.61984 .42283 L
.65954 .44463 L
.69774 .46515 L
.73838 .48653 L
.77751 .50669 L
.81909 .52768 L
.85916 .54751 L
.89771 .56623 L
.93871 .58577 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{455.438, 281.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008i0001Gb000`400?l00000o`00003oo`3ooooo
0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0ooooBP3oool00`2oM000B9cO0?ooo`0;0?ooo`03
0=nLB018W=l0oooo0=l0oooo003o0?ooodT0oooo00<0okmd07Boo`3oool03@3oool00`3OW4P0M;oo
0?ooo`3N0?ooo`00o`3ooom80?ooo`030?oOW018B9`0gooo00h0oooo00<0oooO09a8B02Lgol0gP3o
ool00?l0oooo4`3oool01@3OW4P0000000000000000007Bo0080oooo00X0oono07@0000000000000
07Bo_`1d0000M;oo0?oo_`1d0000M;oo0P3oool00`3ookl0M00007Boo`040?ooo`0:0?noM0000000
00000000000007@0_ooo0?ooo`3ookl0M00007Boo`80oooo00P0oono07@0001d_ol0oooo0;md0000
000004RL0=ooo`L0oooo00L0_g@004RLg`3oool0oooo0?oOW0180000M;oo00L0oooo00H0_g@00000
M02oool0oooo0=nLB000M;oN0?ooo`00o`3ooolB0?ooo`0B0=nLB00004P0W=oo0?ooo`3ooml0W4P0
001d_`3ooml0W4P00018W03Oool0oooO09a800000000M;oo0?oo_`1d0000M;oo0P3oool00`3ookl0
M00007Boo`030?ooo`030=nLB00004P0W=oo0080oooo00H0_g@00000B02Lgol0oono07@0001d_ol2
0?ooo`060?oo_`1d0000M;oo0?oo_`1d0000B9cO203oool00`3ookl0M00007Boo`030?ooo`030;md
0000B9`0gooo00D0oooo00<0omnL04P00018W=l00P3oool00`3o_g@0001d0;ooo`3M0?ooo`00o`3o
oolA0?ooo`030?oo_`1d0000B9cO00D0oooo00<0oono07@00018W=l00P3oool01P3ogi`0B00007Bo
o`3ookl0M00007Boo`80oooo00<0oono07@0001d_ol00P3oool00`3ookl0M00004RLg`060?ooo`03
0?oo_`1d0000M;oo0080oooo00H0oono07@0001d_ol0oono07@0001d_ol80?ooo`030?oOW01804P0
W=oo00<0oooo00<0okmd0000B02Lgol01@3oool00`3OW4P0001809cOo`020?ooo`030?oOW01804P0
W=oo0=d0oooo003o0?oooa40oooo00<0omnL04P0001d_ol01@3oool00`3ookl0M00007Boo`020?oo
o`060?oo_`1d0000M;oo0?oo_`1d0000M;oo0P3oool00`3ookl0M00007Boo`020?ooo`030?oOW018
04P0W=oo00H0oooo00<0oono07@0001d_ol00P3oool01P3ookl0M00007Boo`3ookl0M00007Boo`P0
oooo00<0omnL04P0B02Lgol00`3oool00`3ooml0W4P0001d_`040?ooo`030?oo_`1d000007Bo00<0
oooo00<0omnL04P0B02Lgol0g@3oool00?l0oooo4@3oool00`3ogi`0B01809cOo`050?ooo`030?oo
_`1d0000M;oo0080oooo00H0oono07@0001d_ol0oono07@0001d_ol20?ooo`030?oo_`1d0000M;oo
0080oooo00<0okmd0000000000001@000000101d_ol0oono07@0001d_ol20?ooo`060?oo_`1d0000
M;oo0?oo_`1d0000M;oo203oool00`3ogi`0B01d0;ooo`040?ooo`030=nLB0000000000000D00000
00L0M;oo0?ooo`3oool0oooo0?oOW01804P0W=oo0=d0oooo003o0?oooa40oooo00<0omnL04P0001d
_ol01@3oool00`3ookl0M00007Boo`020?ooo`060?oo_`1d0000M;oo0?oo_`1d0000M;oo0P3oool0
0`3ookl0M00007Boo`020?ooo`030?oOW0180000M;oo00<0oooo00H0omnL04P0001d_ol0oono07@0
001d_ol20?ooo`060?oo_`1d0000M;oo0?oo_`1d0000M;oo203oool00`3ogi`0B01809cOo`040?oo
o`030?oOW0180000B9cO00<0oooo00<0_g@00000M02oool00`3oool00`3ogi`0B01809cOo`3M0?oo
o`00o`3ooolA0?ooo`030?oo_`1d0000B9cO00D0oooo00<0oono07@0001d_ol00P3oool01P3ookl0
M00007Boo`3ookl0M00004RLg`80oooo00<0oono07@00018W=l00P3oool00`3ookl0M00004RLg`03
0?ooo`060?noM00007@0_ooo0?oo_`1d0000B9cO0P3oool01P3ogi`0B00007Boo`3ookl0M00007Bo
o`P0oooo00<0oono07@0001d_ol01@3oool01`2oM00004RL0=ooo`3oool0oono07@00018W=l0103o
ool00`3o_g@0001d0;ooo`3M0?ooo`00o`3ooolB0?ooo`0:0=nLB00004P0W=oo0?ooo`3ookl0M000
04RLg`3ookl0M00007Boo`80oooo00`0oono07@0001d_ol0oono07@00000B9`0gooo0?ooo`3ookl0
M0000018W03Oool20?ooo`0C0=nLB00004P0W=oo0?ooo`3ogi`0B00004RLg`3oool0oono07@00000
04P0W=oo0?ooo`3OW4P0001809cOo`3ookl0M00007Boo`090?ooo`030;md0018W=l0oooo00@0oooo
00L0okmd0000B02Lgol0oooo0=nLB00004P0W=oo00@0oooo00<0gia8001d_`3oool0g@3oool00?l0
oooo4`3oool02@3OW4P0000000000000000007Bo0?ooo`3ookl0M00007Boo`020?ooo`0@0?oo_`1d
0000M;oo0?oo_`1d04P0W9ad0000000007@0_ono07@0B02LW7@000000000M02oool0oooo0?noM0<0
000000L0B9cO0?ooo`3oool0oono07@0001d_kl0M0000080000000<0M;oo0?oOW01800000P000000
0`00B9`0gooo0?ooo`060?ooo`030?oOW018B9`0gooo00@0oooo00H0oooO09a80000M;l0oooO09a8
0000M;l40?ooo`030?oog`2LB4P0W=oo0=h0oooo003o0?oooc`0oooo00<0oono07@0001d_ol02P3o
ool00`3o_g@004RL0=ooo`040?ooo`050=nLB00007@0_mnL04P0001d_ol00`3oool00`3ooml0W4P0
07Boo`3O0?ooo`00o`3oooll0?ooo`030?oo_`1d0000M;oo00/0oooo00<0omnL09boo`3oool00`3o
ool01@3ogi`0B01807AdB00007@0_ooo00<0oooo00<0giad09cOo`3oool0g`3oool00?l0oooo?@3o
ool00`3o_g@0M;oo0?ooo`0A0?ooo`030;md00000000B9cO0>H0oooo003o0?ooool0oooo>`3oool0
0?l0ooooo`3ooolk0?ooo`00o`3ooooo0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0ooooo`3o
oolk0?ooo`00o`3ooooo0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0ooooo`3ooolk0?ooo`00
o`3ooooo0?oooc/0oooo001>0?ooo`050=nLB000000000000000B02Lgol0I`3oool01@3OW4P00000
0000000004P0W=oo0080oooo00<0oooO09a80000M;l00`3oool01@2oM0000000000000000000M;oo
06T0oooo00<0okmd0000M02oool0J@3oool00`3o_g@0001d0;ooo`020?ooo`030?oog`2LB00007Bo
00<0oooo00D0_g@0000000000000000007Boo`1V0?ooo`030=nLB0000000000000@0000000<00018
09cOo`3oool0603oool004d0oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo06D0oooo00L0
okmd0000B02Lgol0oooo0?noM00004P0W=oo00H0oooo00<0_g@0001d_`3oool00P3oool00`2oM000
B9cO0?ooo`1W0?ooo`030?noM00007@0_ooo06T0oooo00<0okmd0000M02oool01`3oool00`2oM000
07Bo0?ooo`020?ooo`030;md0018W=l0oooo06@0oooo00<0omnL04P00018W=l07`3oool004`0oooo
00<0oooO09a80018W=l00`3oool00`2oM00007Bo0?ooo`1S0?ooo`030?oog`2LB000B9cO00<0oooo
00<0_g@0001d_`3oool0103oool00`3ogi`0B00007Boo`030?ooo`030?noM00007@0_ooo06L0oooo
00<0okmd0000M02oool0J@3oool00`3o_g@0001d0;ooo`060?ooo`030?oOW0180000M;oo00<0oooo
00<0okmd0000M02oool0I@3oool00`3OW4P0000007Boo`0N0?ooo`00C03oool00`3ogi`0B00007Bo
o`030?ooo`030=nLB00007@0_ooo06<0oooo00<0omnL04P0001d_ol00`3oool00`3OW4P0001d0;oo
o`0:0?ooo`030?oOW01804P0W=oo06L0oooo00<0okmd0000M02oool0J@3oool00`3o_g@0001d0;oo
o`0<0?ooo`030?oOW01804P0W=oo06H0oooo00<0gia800000018W=l07@3oool004`0oooo00<0omnL
04P0B02Lgol00`3oool00`3o_g@0001d0;ooo`1S0?ooo`030?oOW01804P0W=oo00<0oooo00<0okmd
0000M02oool02P3oool00`3ogi`0B00007Boo`1W0?ooo`030?noM00007@0_ooo06T0oooo00<0okmd
0000M02oool0303oool00`3ogi`0B00007Boo`1W0?ooo`030?noM0000000B9cO01`0oooo001<0?oo
o`030?noM00004P0W=oo00<0oooo00<0okmd0000B02Lgol0H`3oool00`3o_g@0001809cOo`030?oo
o`030?noM00004P0W=oo00X0oooo00<0okmd0000M02oool0I`3oool00`3o_g@0001d0;ooo`1Y0?oo
o`030?noM00007@0_ooo00`0oooo00<0okmd0000M02oool0J03oool00`3o_g@00000001d_`0K0?oo
o`00C03oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo06<0oooo00<0okmd0000B02L
gol00`3oool00`3o_g@0001809cOo`040?ooo`040?oo_`1d000004RL0=ooo`80oooo00<0_g@004RL
g`3oool0I`3oool00`3o_g@0001d0;ooo`1Y0?ooo`030?noM00007@0_ooo00H0oooo00@0oono07@0
0000B9`0gooo0P3oool00`2oM000B9cO0?ooo`1Y0?ooo`030?noM0000000B9cO01X0oooo001<0?oo
o`030?oOW01804P0W=oo00<0oooo00<0okmd0000M02oool0H`3oool00`3ogi`0B01809cOo`030?oo
o`030?noM00007@0_ooo00D0oooo00<0_g@004Q8B00000000P0000000`18W=l0oooo0?ooo`1W0?oo
o`030?noM00007@0_ooo06T0oooo00<0okmd0000M02oool01`3oool00`2oM000B4Q8000000020000
000304RLg`3oool0oooo06X0oooo00<0_g@00000M02oool06@3oool004`0oooo00<0omnL04P0001d
_ol00`3oool00`3OW4P0001d0;ooo`1S0?ooo`030?oOW0180000M;oo00<0oooo00<0gia80000M02o
ool01@3oool00`3OW4P007Bo0?ooo`1Y0?ooo`060?noM0000000B9cO0?noM00007@0_oooIP3oool0
1P3o_g@0000004RLg`3o_g@0001d0;ooo`L0oooo00<0gia8001d_`3oool0K`3oool00`3o_g@00018
09cOo`0I0?ooo`00C03oool00`3ooml0W4P004RLg`030?ooo`030;md0000M;l0oooo06<0oooo00<0
oooO09a80018W=l00`3oool00`2oM00007Bo0?ooo`050?ooo`030?noM00007@0_ooo06X0oooo00D0
okmd000000000000001d0;ooo`1W0?ooo`050?noM000000000000000M02oool01`3oool00`3o_g@0
001d0;ooo`1Y0?ooo`030?oOW0180000M;oo00<0oooo00<0gia80000M02oool06@3oool004d0oooo
00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo06D0oooo00L0okmd0000B02Lgol0oooo0?noM000
04P0W=oo00H0oooo00<0omnL04P0B02Lgol0J`3oool0103ookl0M0000000M02ooomX0?ooo`040?oo
_`1d0000001d0;ooo`L0oooo00<0omnL04P0B02Lgol0J@3oool0203ooml0W4P00000B02Lgol0oooo
0=nLB000000007Bo6P3oool004h0oooo00D0okmd000000000000001809cOo`1W0?ooo`050?noM000
000000000000B02Lgol01`3oool00`3ookl0M0000000000300000003001d_`3oool0oooo06H0oooo
00<0omnL04P0M02oool0J@3oool00`3ogi`0B01d0;ooo`070?ooo`030?oo_`1d0000000000<00000
00<007Bo0?ooo`3oool0I03oool00`3ooml0W4P0000000020000000304RLg`3oool0oooo01T0oooo
003o0?ooool0oooo>`3oool00?l0ooooo`3ooolk0?ooo`00o`3ooooo0?oooc/0oooo003o0?ooool0
oooo>`3oool00?l0ooooo`3ooolk0?ooo`00o`3ooooo0?oooc/0oooo003o0?ooool0oooo>`3oool0
0?l0ooooo`3ooolk0?ooo`00o`3ooooo0?oooc/0oooo00150?ooool00000i000000A0?ooo`00A@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo000f0?ooo`050=nLB0000000
00000000B02Lgol02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00=@3oool01`3o_g@0001809cOo`3o
ool0okmd0000B02Lgol02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00=03oool00`3ooml0W4P004RL
g`030?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?oo
o`0?0?ooo`00=03oool00`3ogi`0B00007Boo`030?ooo`030=nLB00007@0_ooo00P0oooo00<00000
0?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o
0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00=03oool00`3ogi`0B01809cOo`030?oo
o`030?noM00007@0_ooo00P0oooo00<000000?ooo`3oool01`3oool20?l00780oooo00<0001o0?oo
o`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?oo
o`3oool03`3oool003@0oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`@0
00001@3oool50?l00700oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`03
0000O`3oool0oooo07T0oooo1000000A0?ooo`00=03oool00`3o_g@0001809cOo`030?ooo`030?no
M00004P0W=oo00P0oooo00<000000?ooo`3oool01`3oool50?l006l0oooo00<0001o0?ooo`3oool0
L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool0
3`3oool003@0oooo00<0omnL04P0B02Lgol00`3oool00`3o_g@0001d0;ooo`080?ooo`030000003o
ool0oooo00T0oooo103o001^0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3o
ool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000d0?ooo`030?oOW0180000
M;oo00<0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`0:0?ooo`@0o`00K@3oool0
0`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool0
0`000000oooo0?ooo`0?0?ooo`00=03oool00`3ooml0W4P004RLg`030?ooo`030;md0000M;l0oooo
00P0oooo00<000000?ooo`3oool02`3oool40?l006`0oooo00<0001o0?ooo`3oool0L03oool00`00
07l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool003D0
oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0303oool5
0?l006X0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo07`0oooo00<000000?ooo`3oool03`3oool003H0oooo00D0okmd000000000000001809cOo`0:
0?ooo`030000003oool0oooo00d0oooo1@3o001Y0?ooo`030000O`3oool0oooo0700oooo00<0001o
0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?oo
o`030000003oool0oooo00l0oooo103o001X0?ooo`030000O`3oool0oooo0700oooo00<0001o0?oo
o`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`<0
0000403oool40?l006L0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`03
0000O`3oool0oooo07X0oooo0`00000A0?ooo`00A@3oool00`000000oooo0?ooo`0A0?ooo`@0o`00
IP3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0
O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0B0?ooo`D0o`00I03o
ool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03o
ool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0C0?ooo`D0o`00H`3oool0
0`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool0
0`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0E0?ooo`@0o`00HP3oool00`00
07l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`00
0000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0F0?ooo`@0o`00H@3oool00`0007l0
oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000
oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0G0?ooo`@0o`00H03oool00`0007l0oooo
0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo
0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0H0?ooo`@0o`00G`3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?oo
o`0?0?ooo`00A@3oool3000001T0oooo1@3o001M0?ooo`030000O`3oool0oooo0700oooo00<0001o
0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1j0?ooo`<000004@3oool004D0oooo00<000000?oo
o`3oool06P3oool50?l005`0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?oo
o`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3o
ool0703oool40?l005/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`03
0000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0
7@3oool40?l005X0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool07P3o
ool50?l005P0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool07`3oool5
0?l005L0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool08@3oool40?l0
05H0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo
07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool08P3oool40?l005D0
oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0
oooo00<000000?ooo`3oool03`3oool004D0oooo0`00000S0?ooo`D0o`00D`3oool00`0007l0oooo
0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0NP3oool300000140oooo
00150?ooo`030000003oool0oooo02@0oooo1@3o001B0?ooo`030000O`3oool0oooo0700oooo00<0
001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo0015
0?ooo`030000003oool0oooo02H0oooo103o001A0?ooo`030000O`3oool0oooo0700oooo00<0001o
0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?oo
o`030000003oool0oooo02L0oooo103o001@0?ooo`030000O`3oool0oooo0700oooo00<0001o0?oo
o`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`03
0000003oool0oooo02P0oooo1@3o001>0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3o
ool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000
003oool0oooo02T0oooo1@3o001=0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0
K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003o
ool0oooo02/0oooo103o001<0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3o
ool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0
oooo02`0oooo103o001;0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool0
0`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`<00000;@3oool50?l0
04T0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo
07X0oooo0`00000A0?ooo`00A@3oool00`000000oooo0?ooo`0^0?ooo`D0o`00B03oool00`0007l0
oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000
oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0`0?ooo`@0o`00A`3oool00`0007l0oooo
0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo
0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`0a0?ooo`D0o`00A@3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?oo
o`0?0?ooo`00;`3oool00`3o_g@0001d0;ooo`040?ooo`050=nLB000000000000000B02Lgol02P3o
ool00`000000oooo0?ooo`0b0?ooo`D0o`00A03oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3o
ool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00;`3oool0
0`3o_g@0001d0;ooo`030?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030000
003oool0oooo03@0oooo103o00130?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0
K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000_0?ooo`030?noM000
07@0_ooo0080oooo00<0oooO09a80018W=l00`3oool00`2oM00007Bo0?ooo`080?ooo`030000003o
ool0oooo03D0oooo103o00120?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3o
ool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000_0?ooo`030?noM00007@0
_ooo0080oooo00<0omnL04P0001d_ol00`3oool00`3OW4P0001d0;ooo`080?ooo`030000003oool0
oooo03H0oooo1@3o00100?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool0
0`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000_0?ooo`030?noM00007@0_ooo
0080oooo00<0omnL04P0B02Lgol00`3oool00`3o_g@0001d0;ooo`080?ooo`030000003oool0oooo
03L0oooo1@3o000o0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`00
07l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000_0?ooo`030?noM00007@0_ooo0080
oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`@00000>00007l40?l00?l0
001oX00007l400000140oooo000_0?ooo`030?noM00007@0_ooo0080oooo00<0okmd0000B02Lgol0
0`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo03X0oooo103o000m0?ooo`030000
O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000
003oool0oooo00l0oooo000_0?ooo`030?noM00007@0_ooo0080oooo00<0omnL04P0B02Lgol00`3o
ool00`3o_g@0001d0;ooo`080?ooo`030000003oool0oooo03/0oooo1@3o000k0?ooo`030000O`3o
ool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003o
ool0oooo00l0oooo000/0?ooo`060?noM0000000B9cO0?noM00007@0_ooo0P3oool00`3ogi`0B000
07Boo`030?ooo`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0?03oool50?l003X0oooo
00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo
00<000000?ooo`3oool03`3oool002d0oooo00D0okmd000000000000001d0;ooo`020?ooo`030?oo
g`2LB000B9cO00<0oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`0n0?ooo`@0o`00
>@3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0
O03oool00`000000oooo0?ooo`0?0?ooo`00;P3oool0103ookl0M0000000M02oool30?ooo`070?no
M00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030000003oool0oooo03l0oooo1@3o000g0?oo
o`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?oo
o`030000003oool0oooo00l0oooo000_0?ooo`030?oOW01807@0_ooo00@0oooo00D0okmd00000000
0000001809cOo`0:0?ooo`030000003oool0oooo0400oooo1@3o000f0?ooo`030000O`3oool0oooo
0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo
00l0oooo00150?ooo`030000003oool0oooo0440oooo1@3o000e0?ooo`030000O`3oool0oooo0700
oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0
oooo00150?ooo`<00000@`3oool50?l003<0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo
0?ooo`1_0?ooo`030000O`3oool0oooo07X0oooo0`00000A0?ooo`00A@3oool00`000000oooo0?oo
o`140?ooo`D0o`00<P3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0
001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`15
0?ooo`D0o`00<@3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o
0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`170?oo
o`D0o`00;`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?oo
o`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`180?ooo`D0
o`00;P3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3o
ool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`190?ooo`H0o`00
;03oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0
O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1;0?ooo`D0o`00:`3o
ool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03o
ool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1<0?ooo`D0o`00:P3oool0
0`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool0
0`000000oooo0?ooo`0?0?ooo`00A@3oool3000004h0oooo1@3o000X0?ooo`030000O`3oool0oooo
0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1j0?ooo`<000004@3oool004D0
oooo00<000000?ooo`3oool0C`3oool50?l002L0oooo00<0001o0?ooo`3oool0L03oool00`0007l0
oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo
00<000000?ooo`3oool0D03oool50?l002H0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo
0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<0
00000?ooo`3oool0DP3oool50?l002@0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?oo
o`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<00000
0?ooo`3oool0D`3oool50?l002<0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_
0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?oo
o`3oool0E03oool50?l00280oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?oo
o`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3o
ool0EP3oool50?l00200oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`03
0000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0
E`3oool50?l001l0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo0`00001H0?ooo`D0o`007P3o
ool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0NP3o
ool300000140oooo00150?ooo`030000003oool0oooo05X0oooo1@3o000L0?ooo`030000O`3oool0
oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo00150?ooo`030000003oool0oooo05/0oooo1@3o000K0?ooo`030000O`3oool0oooo
0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo
00l0oooo000C0?ooo`030?oo_`1d0000M;oo02l0oooo00<000000?ooo`3oool0G03oool60?l001T0
oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0
oooo00<000000?ooo`3oool03`3oool001<0oooo00<0oono07@0001d_ol0;`3oool00`000000oooo
0?ooo`1N0?ooo`D0o`00603oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo
00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`004`3oool00`3ookl0M00007Bo
o`0_0?ooo`030000003oool0oooo05l0oooo1@3o000G0?ooo`030000O`3oool0oooo0700oooo00<0
001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000C
0?ooo`030?oo_`1d0000M;oo02l0oooo00<000000?ooo`3oool0H@3oool50?l001D0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<00000
0?ooo`3oool03`3oool001<0oooo00<0oono07@0000000002@0000000`0007@0_ooo0?ooo`0S0?oo
o`030000003oool0oooo0680oooo1@3o000D0?ooo`030000O`3oool0oooo0700oooo00<0001o0?oo
o`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000C0?ooo`03
0?oo_`1d0000M;oo02l0oooo0`00001S0?ooo`D0o`004`3oool00`0007l0oooo0?ooo`1`0?ooo`03
0000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0NP3oool300000140oooo000C0?ooo`030?oo
_`1d0000M;oo02l0oooo00<000000?ooo`3oool0I@3oool50?l00140oooo00<0001o0?ooo`3oool0
L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool0
3`3oool001<0oooo00<0oono07@0001d_ol0;`3oool00`000000oooo0?ooo`1V0?ooo`D0o`00403o
ool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03o
ool00`000000oooo0?ooo`0?0?ooo`004`3oool00`3ookl0M00007Boo`0_0?ooo`030000003oool0
oooo06L0oooo1@3o000?0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool0
0`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000[0?ooo`030=nLB00000000000
00@0000000D0001809cOo`3oool0oooo0=nLB002000000030000B02Lgol0oooo00T0oooo00<00000
0?ooo`3oool0J@3oool50?l000d0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_
0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool002/0oooo00<0omnL04P0
0018W=l01`3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol02@3oool00`000000oooo0?oo
o`1Z0?ooo`D0o`00303oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0
001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00603oool00`3ookl0M00000000002
000000030000B02Lgol0oooo00`0oooo00<0gia80000001d_ol01@3oool00`3ooml0W4P004RLg`03
0?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0J`3oool50?l000/0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<00000
0?ooo`3oool03`3oool001L0oooo00T0okmd0000001d_ol0gia80018W03Oool0gia80000001d_ol0
3@3oool00`3OW4P0000004RLg`040?ooo`030?oOW0180000M;oo00<0oooo00<0gia80000M02oool0
203oool00`000000oooo0?ooo`1]0?ooo`D0o`002@3oool00`0007l0oooo0?ooo`1`0?ooo`030000
O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3o
ool02`3ooml0W4P0001d_`3oool0gia80018W03Oool0oooo0;md0000B9`0gooo00d0oooo00<0okmd
00000018W=l00`3oool00`3ogi`0B01809cOo`030?ooo`030?noM00007@0_ooo00P0oooo00<00000
0?ooo`3oool0KP3oool50?l000P0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_
0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00/0oono07@0
0018W=l0oooo0=nLB000B9`0gooo0?ooo`3o_g@0001d0;ooo`0>0?ooo`030?noM000000007Bo0080
oooo00<0okmd0000B02Lgol00`3oool00`3o_g@0001809cOo`080?ooo`@00000KP0007l60?l00?l0
001oJ00007l400000140oooo000F0?ooo`0;0?oog`2LB000B9cO0?ooo`3OW4P004RL0=ooo`3oool0
gia80000M02oool03`3oool01`3o_g@0000004RLg`3oool0okmd0000B02Lgol00`3oool00`3o_g@0
001809cOo`080?ooo`030000003oool0oooo0740oooo1@3o00050?ooo`030000O`3oool0oooo0700
oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0
oooo000G0?ooo`090?noM00004P0W=oo0=nLB000B9`0gooo0?oo_`1d0000B9cO0140oooo00H0_g@0
0000M02oool0omnL04P0B02Lgol30?ooo`030?noM00007@0_ooo00P0oooo00<000000?ooo`3oool0
LP3oool50?l000@0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001P0oooo00L0oono07@00000000004RL
0=ooo`2oM000B9cO0180oooo00H0okmd0000B02Lgol0omnL04P0001d_ol30?ooo`030=nLB00007@0
_ooo00P0oooo00<000000?ooo`3oool0M03oool50?l00080oooo00<0001o0?ooo`3oool0L03oool0
0`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool0
02/0oooo00<0omnL04P0001d_ol00`3oool01P3OW4P0001d0;ooo`3ooml0W4P004RLg`<0oooo00<0
_g@0001d_`3oool0203oool00`000000oooo0?ooo`1e0?ooo`D0o`0000<0oooo0000O`3oool0L@3o
ool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3o
ool002/0oooo00P0oooO09a8000004P0W=oo0?ooo`3OW4P00000001d_`80oooo00L0okmd0000B02L
gol0oooo0?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0MP3oool50?l000030000O`3oool0
oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo000F0?ooo`030?oo_`1d0000000000H0000000<0001d0;ooo`3oool02P3oool00`3o
oml0W4P0000000020000000304RLg`3oool0oooo0080oooo00D0okmd000000000000001809cOo`0:
0?ooo`030000003oool0oooo07P0oooo1@3o001a0?ooo`030000O`3oool0oooo06l0oooo00<0001o
0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005`3oool00`3ogi`0B00007Boo`0[0?oo
o`030000003oool0oooo07T0oooo1@3o001`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?oo
o`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`3ooml0W4P004RLg`0/0?ooo`<0
0000NP3oool60?l006h0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1j0?ooo`<0
00004@3oool001H0oooo00<0oono07@00018W=l0;03oool00`000000oooo0?ooo`1k0?ooo`030000
O`3o0000o`0000<0o`00K@3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo
00<000000?ooo`3oool03`3oool001H0oooo00@0oooO09a80000B9`0gooo:`3oool00`000000oooo
0?ooo`1k0?ooo`030000O`3oool0o`0000@0o`00K03oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001L0oooo00<0oono07@0000000001@00
00000`0007@0_ooo0?ooo`0S0?ooo`030000003oool0oooo07/0oooo00@0001o0?ooo`3oool0oooo
1@3o001Z0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo
0?ooo`0?0?ooo`005`3oool00`3ogi`0B01809cOo`0[0?ooo`030000003oool0oooo07/0oooo00<0
001o0?ooo`3oool00P3oool50?l006T0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?oo
o`1l0?ooo`030000003oool0oooo00l0oooo000F0?ooo`030?oog`2LB000B9cO02`0oooo00<00000
0?ooo`3oool0N`3oool00`0007l0oooo0?ooo`030?ooo`H0o`00I`3oool00`0007l0oooo0?ooo`1_
0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00<0oono07@0
0018W=l0;03oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo00D0oooo1@3o001V0?oo
o`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?oo
o`005P3oool0103ooml0W4P00018W03Oool[0?ooo`030000003oool0oooo07/0oooo00<0001o0?oo
o`3oool01P3oool60?l006@0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?oo
o`030000003oool0oooo00l0oooo000G0?ooo`030?oo_`1d0000000000D0000000<0001d0;ooo`3o
ool08`3oool3000007/0oooo00<0001o0?ooo`3oool0203oool50?l006<0oooo00<0001o0?ooo`3o
ool0K`3oool00`0007l0oooo0?ooo`1j0?ooo`<000004@3oool004D0oooo00<000000?ooo`3oool0
N`3oool00`0007l0oooo0?ooo`090?ooo`D0o`00HP3oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3o
ool00`0007l0oooo0?ooo`0;0?ooo`D0o`00H03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00<0oono07@0000000002@000000
0`0004P0W=oo0?ooo`0P0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0303oool5
0?l005l0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo000G0?ooo`030?oOW0180000M;oo00<0oooo00<0gia80000001d_ol09@3oool00`00
0000oooo0?ooo`1k0?ooo`030000O`3oool0oooo00d0oooo1P3o001M0?ooo`030000O`3oool0oooo
06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`3ooml0
W4P004RLg`050?ooo`030=nLB000B9`0gooo02@0oooo00<000000?ooo`3oool0N`3oool00`0007l0
oooo0?ooo`0?0?ooo`D0o`00G03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0
oooo00<000000?ooo`3oool03`3oool001H0oooo00<0oono07@0B02Lgol01@3oool00`3o_g@0001d
0;ooo`0T0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0403oool60?l005X0oooo
00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo
000F0?ooo`030?oog`2LB000M;oo00D0oooo00<0_g@00018W03Oool0903oool00`000000oooo0?oo
o`1k0?ooo`030000O`3oool0oooo0180oooo1@3o001I0?ooo`030000O`3oool0oooo06l0oooo00<0
001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005`3oool00`3o_g@0000007Boo`03
0?ooo`030=nLB00004P0W=oo02D0oooo0`00001k0?ooo`030000O`3oool0oooo01<0oooo1P3o001G
0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0NP3oool300000140oooo000H0?oo
o`030?oo_`1d000000000080000000<004RL0=ooo`3oool09@3oool00`000000oooo0?ooo`1k0?oo
o`030000O`3oool0oooo01D0oooo1@3o001F0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?oo
o`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`03
0000O`3oool0oooo01H0oooo1@3o001E0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3o
ool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000
O`3oool0oooo01P0oooo1@3o001C0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0
O03oool00`000000oooo0?ooo`0?0?ooo`00603oool00`3ookl0M00000000002000000030000B02L
gol0oooo02D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`0I0?ooo`D0o`00DP3o
ool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3o
ool001L0oooo00T0okmd0000001d_ol0gia80018W03Oool0gia80000001d_ol09@3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo01X0oooo1P3o001@0?ooo`030000O`3oool0oooo06l0
oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3oool02`3ooml0W4P0
001d_`3oool0gia80018W03Oool0oooo0;md0000B9`0gooo02@0oooo00<000000?ooo`3oool0N`3o
ool00`0007l0oooo0?ooo`0L0?ooo`D0o`00C`3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00/0oono07@00018W=l0oooo0=nL
B000B9`0gooo0?ooo`3o_g@0001d0;ooo`0T0?ooo`030000003oool0oooo07/0oooo00<0001o0?oo
o`3oool07@3oool60?l004d0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?oo
o`030000003oool0oooo00l0oooo000F0?ooo`0;0?oog`2LB000B9cO0?ooo`3OW4P004RL0=ooo`3o
ool0gia80000M02oool0903oool3000007/0oooo00<0001o0?ooo`3oool07`3oool50?l004`0oooo
00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1j0?ooo`<000004@3oool001L0oooo00T0
okmd0000B02Lgol0gia80018W03Oool0oono07@00018W=l09@3oool00`000000oooo0?ooo`1k0?oo
o`030000O`3oool0oooo0200oooo1P3o001:0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?oo
o`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00603oool01`3ookl0M00000000000B9`0gooo
0;md0018W=l09P3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0280oooo1@3o0019
0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?
0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo02<0oooo1P3o00170?oo
o`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?oo
o`00;@3oool01@2oM0000000000000000000M;oo00@0oooo00D0gia8000000000000001809cOo`0:
0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool09@3oool60?l004D0oooo00<0001o
0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000F0?oo
o`030?oo_`1d0000000000H0000000<0001d0;ooo`3oool02P3oool01`2oM00004RL0=ooo`3oool0
oooO09a80018W=l00P3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol02@3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo02H0oooo1P3o00140?ooo`030000O`3oool0oooo06l0
oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005`3oool00`3o_g@0001d
0;ooo`0A0?ooo`030?oOW0180000M;oo00<0oooo00H0okmd0000M02oool0oooO09a80018W=l30?oo
o`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`0X0?oo
o`H0o`00@P3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?oo
o`3oool03`3oool001H0oooo00<0oono07@00018W=l0603oool01P3ogi`0B00007Boo`3ogi`0B000
07Boo`<0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0
oooo02X0oooo1@3o00110?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool0
0`000000oooo0?ooo`0?0?ooo`005P3oool00`3ooml0W4P004RLg`0H0?ooo`060?noM00004P0W=oo
0?oOW01804P0W=oo0`3oool00`3o_g@0001d0;ooo`080?ooo`@00000Z00007l60?l00?l0001o;P00
07l400000140oooo000`0?ooo`070?oog`2LB00004RL0=ooo`3o_g@0001809cOo`030?ooo`030?no
M00004P0W=oo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`0]0?ooo`D0o`00
?P3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool0
3`3oool001P0oooo00P0_g@0001d_`3oool0oono07@000000000001d0;ooo`h0oooo00@0okmd0000
00000000B9cO0P3oool00`3o_g@0001809cOo`030?ooo`030?noM00004P0W=oo00P0oooo00<00000
0?ooo`3oool0N`3oool00`0007l0oooo0?ooo`0^0?ooo`H0o`00?03oool00`0007l0oooo0?ooo`1_
0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001L0oooo00X0gia80000
M02oool0oooo0;md0018W=l0oooo0=nLB000B9`0gooo3`3oool01`3OW4P0001809cOo`3oool0omnL
04P0B02Lgol00`3oool00`3o_g@0001d0;ooo`080?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0<03oool60?l003X0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l
0?ooo`030000003oool0oooo00l0oooo000F0?ooo`0;0?oog`2LB000B9cO0?ooo`3ookl0M01809cO
o`3oool0omnL04P0M02oool03`3oool01`3ooml0W4P0001d_`3oool0omnL04P0001d_ol00`3oool0
0`3OW4P0001d0;ooo`080?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0<@3oool6
0?l003T0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo000F0?ooo`0;0?oo_`1d0000B9cO0?ooo`3ogi`0B01d0;ooo`3oool0omnL04P0M02o
ool02P3oool00`3ookl0M00004RLg`020?ooo`070?oog`2LB00007Bo0?ooo`3ooml0W4P004RLg`03
0?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`0c
0?ooo`H0o`00=`3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<00000
0?ooo`3oool03`3oool001H0oooo00/0oooO09a80018W=l0oooo0?noM000B9`0gooo0?ooo`3OW4P0
04RL0=ooo`0;0?ooo`070=nLB00007@0_ooo0?ooo`3o_g@0001809cOo`020?ooo`070?noM00004P0
W=oo0?ooo`3o_g@0001809cOo`090?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0
=@3oool50?l003H0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000
003oool0oooo00l0oooo000G0?ooo`090;md0000B9`0gooo0=nLB000M;l0oooo0?oOW0180000M;oo
00d0oooo00D0gia8000000000000001809cOo`040?ooo`050?noM000000000000000B02Lgol02P3o
ool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo03H0oooo1P3o000d0?ooo`030000O`3o
ool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005`3oool0
0`3ookl0M00000000005000000030000M02oool0oooo02<0oooo00<000000?ooo`3oool0N`3oool0
0`0007l0oooo0?ooo`0h0?ooo`H0o`00<P3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo0`00001k0?ooo`030000O`3oool0oooo
03T0oooo1P3o000a0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0NP3oool30000
0140oooo000F0?ooo`030?oo_`1d04P0W=oo02`0oooo00<000000?ooo`3oool0N`3oool00`0007l0
oooo0?ooo`0k0?ooo`H0o`00;`3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0
oooo00<000000?ooo`3oool03`3oool001@0oooo00<0_g@0000000000000200000000`18W=l0oooo
0?ooo`0S0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0?@3oool50?l002h0oooo
00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo
000F0?ooo`030?oo_`1d04P0W=oo00D0oooo00<0gia80000M02oool0903oool00`000000oooo0?oo
o`1k0?ooo`030000O`3oool0oooo03h0oooo1P3o000/0?ooo`030000O`3oool0oooo06l0oooo00<0
001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3oool00`3ookl0M01809cOo`05
0?ooo`030?noM00007@0_ooo02@0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`10
0?ooo`D0o`00:`3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<00000
0?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`110?oo
o`H0o`00:@3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?oo
o`3oool03`3oool001H0oooo00<0oono07@0000000001@0000000`00B9`0gooo0?ooo`0T0?ooo`03
0000003oool0oooo07/0oooo00<0001o0?ooo`3oool0@`3oool60?l002L0oooo00<0001o0?ooo`3o
ool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000M0?ooo`030?oo
_`1d000007Bo02D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`140?ooo`H0o`00
9P3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool0
3`3oool001h0oooo00<0gia80000M02oool0903oool3000007/0oooo00<0001o0?ooo`3oool0AP3o
ool60?l002@0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1j0?ooo`<000004@3o
ool001h0oooo00<0okmd0000M02oool0903oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0
oooo04P0oooo1@3o000S0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool0
0`000000oooo0?ooo`0?0?ooo`007P3oool00`2oM00007Bo0?ooo`0T0?ooo`030000003oool0oooo
07/0oooo00<0001o0?ooo`3oool0B@3oool60?l00240oooo00<0001o0?ooo`3oool0K`3oool00`00
07l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000M0?ooo`030?noM00007@0_ooo02D0
oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1;0?ooo`H0o`007`3oool00`0007l0
oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo
00<0oono07@0000000001P0000000`0007@0_ooo0?ooo`0S0?ooo`030000003oool0oooo07/0oooo
00<0001o0?ooo`3oool0C03oool60?l001h0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo
0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0
001o0?ooo`3oool0CP3oool60?l001`0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?oo
o`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0D03oool50?l001/0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l
0?ooo`030000003oool0oooo00l0oooo000F0?ooo`030?oo_`1d0000000000H0000000<0001d0;oo
o`3oool08`3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0540oooo1P3o000I0?oo
o`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?oo
o`005`3oool00`3o_g@0001d0;ooo`0[0?ooo`<00000N`3oool00`0007l0oooo0?ooo`1C0?ooo`D0
o`00603oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07X0oooo0`00000A0?ooo`00
5P3oool00`3ookl0M00004RLg`0/0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0
E03oool60?l001H0oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000
003oool0oooo00l0oooo000F0?ooo`030?oog`2LB000B9cO02`0oooo00<000000?ooo`3oool0N`3o
ool00`0007l0oooo0?ooo`1F0?ooo`H0o`00503oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo07`0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool0
0`0007l0oooo0?ooo`1G0?ooo`H0o`004`3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo07`0oooo00<000000?ooo`3oool03`3oool001P0oooo00<0oono07@0000000000P0000000`00
04P0W=oo0?ooo`0U0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0F@3oool60?l0
0140oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo
00l0oooo000G0?ooo`090?noM0000000M;oo0=nLB000B9`0gooo0=nLB0000000M;oo02D0oooo00<0
00000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1K0?ooo`H0o`003`3oool00`0007l0oooo0?oo
o`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00/0oooO
09a80000M;l0oooo0=nLB000B9`0gooo0?ooo`2oM00004RL0=ooo`0T0?ooo`030000003oool0oooo
07/0oooo00<0001o0?ooo`3oool0G03oool60?l000h0oooo00<0001o0?ooo`3oool0K`3oool00`00
07l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000F0?ooo`0;0?oo_`1d0000B9cO0?oo
o`3OW4P004RL0=ooo`3oool0okmd0000M02oool0903oool00`000000oooo0?ooo`1k0?ooo`030000
O`3oool0oooo05h0oooo1P3o000<0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0
O03oool00`000000oooo0?ooo`0?0?ooo`005P3oool02`3ooml0W4P004RLg`3oool0gia80018W03O
ool0oooo0=nLB00007@0_ooo02@0oooo0`00001k0?ooo`030000O`3oool0oooo0600oooo1P3o000:
0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0NP3oool300000140oooo000G0?oo
o`090?noM00004P0W=oo0=nLB000B9`0gooo0?oo_`1d0000B9cO02D0oooo00<000000?ooo`3oool0
N`3oool00`0007l0oooo0?ooo`1Q0?ooo`H0o`002@3oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001P0oooo00L0oono07@00000000004RL
0=ooo`2oM000B9cO02H0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1S0?ooo`H0
o`001`3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3o
ool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1U0?ooo`H0o`00
1@3oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool0
3`3oool00300oooo00<0_g@00018W03Oool00`3oool01@3OW4P000000000000004P0W=oo00X0oooo
00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1V0?ooo`L0o`000`3oool00`0007l0oooo
0?ooo`1_0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool00300oooo00<0
_g@00018W03Oool00P3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol02@3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo06P0oooo1P3o00020?ooo`030000O`3oool0oooo06l0
oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00<03oool01`2oM00004RL
0=ooo`3oool0oooO09a80018W=l00`3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo
07/0oooo00<0001o0?ooo`3oool0JP3oool60?l000030000O`3oool0oooo06l0oooo00<0001o0?oo
o`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00:`3oool00`3OW4P000000000000500000004
07Boo`3ogi`0B00007Boo`<0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`1k0?oo
o`030000O`3oool0oooo06`0oooo1P3o001`0?ooo`030000O`3oool0oooo07`0oooo00<000000?oo
o`3oool03`3oool002/0oooo00<0omnL04P0B02Lgol00P3oool01`2oM00004RL0=ooo`3oool0omnL
04P0B02Lgol00`3oool00`3o_g@0001d0;ooo`080?ooo`@00000jP0007l70?l00>X0001o1000000A
0?ooo`00;03oool02`3OW4P004RL0=ooo`3oool0_g@00018W03Oool0oooo0?noM00004P0W=oo00<0
oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo06l0
oooo1P3o001]0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool002`0oooo
00/0oooO09a80018W=l0oooo0;md0000B9`0gooo0?ooo`3o_g@0001809cOo`030?ooo`030?noM000
04P0W=oo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3o
0000o`0000@0o`00J`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000F
0?ooo`030?oo_`1d0000000000H0000000<0001d0;ooo`3oool02`3oool02P3ogi`0B01809cOo`2o
M00004RL0=ooo`3oool0omnL04P0B02Lgol30?ooo`030?noM00007@0_ooo00P0oooo00<000000?oo
o`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo00H0o`00J@3oool00`00
07l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000G0?ooo`030?noM00007@0_ooo01@0
oooo00T0gia80018W02LM00004RL0=ooo`3oool0omnL04P0001d_ol00`3oool00`3OW4P0001d0;oo
o`080?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool0100007l0oooo0?oo
o`3oool60?l006P0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3o
ool00`3ookl0M00004RLg`0E0?ooo`090?oo_`1d000000000018W03Oool0oooo0?oog`2LB000B9cO
00<0oooo00<0_g@0001d_`3oool0203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo
0700oooo00<0001o0?ooo`3oool00`3oool60?l006H0oooo00<0001o0?ooo`3oool0O03oool00`00
0000oooo0?ooo`0?0?ooo`005P3oool00`3ooml0W4P004RLg`0F0?ooo`040?noM000000004RL0=oo
o`80oooo00L0okmd0000B02Lgol0oooo0?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0N`3o
ool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo00D0oooo1P3o001T0?ooo`030000O`3o
ool0oooo07`0oooo00<000000?ooo`3oool03`3oool00300oooo00<0_g@00018W03Oool00`3oool0
1@3o_g@000000000000004P0W=oo00X0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo00H0oooo1`3o001R0?ooo`030000O`3oool0oooo07`0oooo00<0
00000?ooo`3oool03`3oool001<0oooo00D0oono07@00018W=l0oono07@00007000000030000M02o
ool0oooo02<0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3o
ool0oooo00P0oooo1P3o001Q0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3o
ool004D0oooo0`00001k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool02P3oool6
0?l005l0oooo00<0001o0?ooo`3oool0NP3oool300000140oooo00150?ooo`030000003oool0oooo
07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`0<0?ooo`H0o`00G@3oool00`00
07l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0
oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`0=0?ooo`L0o`00F`3oool00`0007l0
oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000G0?ooo`080?oo_`1d000000000000B02L
gol0oooO09a80000M;lV0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool0
0`0007l0oooo0?ooo`0?0?ooo`H0o`00FP3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo000G0?ooo`090;md0000M;l0oooO09a80000B9`0gooo0?oo_`1d000007Bo02D0oooo
00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo0140oooo
1P3o001H0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00/0
oono07@00018W=l0oooo0;md000004P0W=oo0?ooo`3OW4P0001d0;ooo`0T0?ooo`030000003oool0
oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`0C0?ooo`H0o`00EP3oool0
0`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000F0?ooo`0;0?oog`2LB000B9cO
0?ooo`3o_g@0000007Boo`3oool0okmd0000M02oool0903oool00`000000oooo0?ooo`1k0?ooo`03
0000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0503oool60?l005D0oooo00<0001o0?ooo`3o
ool0O03oool00`000000oooo0?ooo`0?0?ooo`005`3oool02@2oM00004RL0=ooo`3ookl0M000001d
_`3oool0_g@0001d_`0U0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool0
0`0007l0oooo0?ooo`0F0?ooo`H0o`00D`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo000G0?ooo`050?oo_`1d0000B9cO0?ooo`3OW4P00P0000000`00B9`0gooo0?ooo`0T
0?ooo`<00000N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo01P0oooo1P3o001A
0?ooo`030000O`3oool0oooo07X0oooo0`00000A0?ooo`00A@3oool00`000000oooo0?ooo`1k0?oo
o`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool06@3oool70?l004l0oooo00<0001o0?oo
o`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`03
0000O`3oool0oooo0700oooo00<0001o0?ooo`3oool06`3oool60?l004h0oooo00<0001o0?ooo`3o
ool0O03oool00`000000oooo0?ooo`0?0?ooo`00603oool00`3ookl0M00000000002000000030000
B02Lgol0oooo02D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000
O`3oool0oooo01d0oooo1P3o001<0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool0
3`3oool001L0oooo00T0okmd0000001d_ol0gia80018W03Oool0gia80000001d_ol09@3oool00`00
0000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool07`3oool60?l0
04X0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005P3oool02`3ooml0
W4P0001d_`3oool0gia80018W03Oool0oooo0;md0000B9`0gooo02@0oooo00<000000?ooo`3oool0
N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo0200oooo1`3o00180?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00/0oono07@00018W=l0oooo
0=nLB000B9`0gooo0?ooo`3o_g@0001d0;ooo`0T0?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`0R0?ooo`H0o`00A`3oool00`0007l0oooo0?ooo`1l
0?ooo`030000003oool0oooo00l0oooo000F0?ooo`0;0?oog`2LB000B9cO0?ooo`3OW4P004RL0=oo
o`3oool0gia80000M02oool0903oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700
oooo00<0001o0?ooo`3oool0903oool60?l004D0oooo00<0001o0?ooo`3oool0O03oool00`000000
oooo0?ooo`0?0?ooo`005`3oool02@3o_g@0001809cOo`3OW4P004RL0=ooo`3ookl0M00004RLg`0U
0?ooo`<00000N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo02H0oooo1P3o0013
0?ooo`030000O`3oool0oooo07X0oooo0`00000A0?ooo`00603oool01`3ookl0M00000000000B9`0
gooo0;md0018W=l09P3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0
001o0?ooo`3oool09`3oool60?l00480oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?oo
o`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o
0?ooo`3oool0:@3oool60?l00400oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?
0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?oo
o`3oool0:`3oool60?l003h0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?oo
o`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3o
ool0;03oool70?l003`0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00
A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0
;P3oool60?l003/0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3o
ool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0<03o
ool60?l003T0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool0
0`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0<P3oool6
0?l003L0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00603oool00`3O
W4P00000000000040000000307Boo`3oool0oooo02<0oooo0`00001k0?ooo`030000O`3oool0oooo
0700oooo00<0001o0?ooo`3oool0<`3oool70?l003D0oooo00<0001o0?ooo`3oool0NP3oool30000
0140oooo000F0?ooo`030?noM0000000B9cO00H0oooo00<0_g@00000B02Lgol08`3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0=@3oool70?l003<0
oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`005@3oool00`3ogi`0B7Bo
0?ooo`080?ooo`030?oog`2LB7@0_ooo0280oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo
0?ooo`1`0?ooo`030000O`3oool0oooo03L0oooo1P3o000b0?ooo`030000O`3oool0oooo07`0oooo
00<000000?ooo`3oool03`3oool001D0oooo00<0_ibL0=ooo`3oool02@3oool00`3ookl0W9cO0?oo
o`0Q0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?oo
o`0i0?ooo`H0o`00<03oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000]
0?ooo`050;md0000000000000000001d_ol0103oool01@3OW4P000000000000004P0W=oo00X0oooo
00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo03/0oooo
1P3o000^0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001H0oooo00<0
oooO09a8000000000`0000000`00M;l0oooo0?ooo`0=0?ooo`030;md0000M;l0oooo0080oooo00/0
_g@004RLg`3oool0oooo0?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030000003oool0
oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`0l0?ooo`L0o`00;03oool0
0`0007l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000E0?ooo`030?noM0000000B9cO
00@0oooo00<0gia800000018W=l0303oool00`3ogi`0B00007Boo`030?ooo`060?noM00007@0_ooo
0?oog`2LB000B9cO0`3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo07/0oooo00<0
001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`0n0?ooo`L0o`00:P3oool00`0007l0oooo0?oo
o`1l0?ooo`030000003oool0oooo00l0oooo000D0?ooo`030?oOW0180000M;oo00H0oooo00<0omnL
04P0001d_ol04@3oool01P3ogi`0B01809cOo`3ogi`0B00007Boo`<0oooo00<0gia80000M02oool0
203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0
@03oool60?l002T0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00503o
ool00`2oM00007Bo0?ooo`070?ooo`030;md0000B9`0gooo0100oooo00H0omnL04P0001d_ol0omnL
04P0B02Lgol30?ooo`030?noM00007@0_ooo00P0oooo1000003o0000Oc<0001o1P3o002S0000O`@0
00004@3oool001<0oooo00<0oono07@00018W=l0203oool00`3OW4P0001d0;ooo`0@0?ooo`060?no
M00007@0_ooo0?noM00004P0W=oo0`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo
07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`140?ooo`H0o`009@3oool00`00
07l0oooo0?ooo`1l0?ooo`030000003oool0oooo00l0oooo000C0?ooo`030?oo_`1d0000M;oo00P0
oooo00<0okmd0000M02oool02P3oool0103ookl0M0000018W03Oool20?ooo`060;md0018W=l0oooo
0?noM00004P0W=oo0`3oool00`3o_g@0001809cOo`080?ooo`030000003oool0oooo07/0oooo00<0
001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`150?ooo`L0o`008`3oool00`0007l0oooo0?oo
o`1l0?ooo`030000003oool0oooo00l0oooo000C0?ooo`030?oog`2LB000B9cO00P0oooo00<0gia8
0018W03Oool02`3oool00`2oM000B4Q8000000020000000604RLg`3oool0oooo0?oOW01804P0W=oo
0`3oool00`3o_g@0001d0;ooo`080?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0
L03oool00`0007l0oooo0?ooo`170?ooo`L0o`008@3oool00`0007l0oooo0?ooo`1l0?ooo`030000
003oool0oooo00l0oooo000D0?ooo`030;md0000B9`0gooo00H0oooo00<0oono07@00018W=l0303o
ool00`3OW4P007Bo0?ooo`050?ooo`030?oOW0180000M;oo00<0oooo00<0gia80000M02oool0203o
ool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0B@3o
ool60?l00200oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00503oool0
103ookl0M0000018W03Oool40?ooo`040?oo_`1d000004RL0=ooo``0oooo00<0okmd0000M02oool0
1@3oool00`3ooml0W4P004RLg`030?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0
N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo04/0oooo1P3o000N0?ooo`030000
O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001D0oooo00<0oooO09a80000M;l00`3o
ool00`3ogi`0B00004RLg`0>0?ooo`030?oOW01804P0W=oo00H0oooo00L0okmd0000B02Lgol0oooo
0?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`03
0000O`3oool0oooo04d0oooo1P3o000L0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3o
ool03`3oool002`0oooo00<0oono07@0000000000`0000001@00M;l0oooo0?ooo`3oool0okmd0080
000000<0001809cOo`3oool02@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700
oooo00<0001o0?ooo`3oool0CP3oool70?l001X0oooo00<0001o0?ooo`3oool0O03oool00`000000
oooo0?ooo`0?0?ooo`005@3oool00`2oM7@0_ooo0?ooo`090?ooo`030?noM018W=l0oooo0240oooo
00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo0500oooo
1`3o000H0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001D0oooo00<0
oono07@0M02oool0203oool00`3o_g@007Bo0?ooo`0R0?ooo`<00000N`3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo0580oooo1P3o000G0?ooo`030000O`3oool0oooo07X0oooo0`00
000A0?ooo`005P3oool0103ookl0M0000018W03Oool40?ooo`030?oo_`1d000007Bo02@0oooo00<0
00000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo05@0oooo1P3o
000E0?ooo`030000O`3oool0oooo07`0oooo00<000000?ooo`3oool03`3oool001P0oooo00<0omnL
04P0000000000`0000000`0007@0_ooo0?ooo`0T0?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1F0?ooo`H0o`004`3oool00`0007l0oooo0?ooo`1l
0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?oo
o`3oool0L03oool00`0007l0oooo0?ooo`1G0?ooo`L0o`004@3oool00`0007l0oooo0?ooo`1l0?oo
o`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3o
ool0L03oool00`0007l0oooo0?ooo`1I0?ooo`L0o`003`3oool00`0007l0oooo0?ooo`1l0?ooo`03
0000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0
L03oool00`0007l0oooo0?ooo`1K0?ooo`L0o`003@3oool00`0007l0oooo0?ooo`1l0?ooo`030000
003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03o
ool00`0007l0oooo0?ooo`1M0?ooo`L0o`002`3oool00`0007l0oooo0?ooo`1l0?ooo`030000003o
ool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool0
0`0007l0oooo0?ooo`1O0?ooo`L0o`002@3oool00`0007l0oooo0?ooo`1l0?ooo`030000003oool0
oooo00l0oooo00150?ooo`<00000N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo
0640oooo1`3o00070?ooo`030000O`3oool0oooo07X0oooo0`00000A0?ooo`00A@3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0H`3oool70?l000D0
oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo
0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0I@3oool70?l000<0oooo
00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?oo
o`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0I`3oool70?l000030?ooo`00
07l0oooo07d0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool0
0`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06T0oooo1`3o001n0?ooo`030000003oool0
oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`00
07l0oooo0?ooo`1[0?ooo`L0o`00O03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K@3oool70?l007X0
oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo
0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo1P3o001i0?ooo`030000003oool0oooo00l0oooo
00150?ooo`<00000N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0
001o0?ooo`3o00001@3o001e0?ooo`<000004@3oool004D0oooo00<000000?ooo`3oool0N`3oool0
0`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00@0001o0?ooo`3oool0oooo1P3o
001e0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo0080oooo1`3o001c
0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?oo
o`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo00@0oooo1`3o001a0?oo
o`030000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3o
ool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo00H0oooo1P3o001`0?ooo`03
0000003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0
L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo00P0oooo1P3o001^0?ooo`030000
003oool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03o
ool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo00X0oooo1P3o001/0?ooo`030000003o
ool0oooo00l0oooo00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool0
0`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo00/0oooo1`3o001Z0?ooo`030000003oool0
oooo00l0oooo00150?ooo`<00000N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo
06l0oooo00<0001o0?ooo`3oool03@3oool70?l006H0oooo0`00000A0?ooo`00A@3oool00`000000
oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0
oooo0?ooo`0?0?ooo`L0o`00IP3oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo
0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo
0?ooo`0A0?ooo`L0o`00I03oool00`000000oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?oo
o`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?oo
o`0C0?ooo`L0o`00HP3oool00`000000oooo0?ooo`0?0?ooo`00;@3oool01@3o_g@0000000000000
0000B9cO00@0oooo00D0gia8000000000000001809cOo`0:0?ooo`030000003oool0oooo07/0oooo
00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo01D0oooo
1`3o001P0?ooo`030000003oool0oooo00l0oooo000/0?ooo`070=nLB000B9`0gooo0?ooo`3ooml0
W4P004RLg`020?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030000003oool0
oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo01L0oooo1`3o001N0?ooo`030000003oool0oooo00l0oooo000[0?ooo`030?oo_`1d0000M;oo
00<0oooo00H0okmd0000M02oool0oooO09a80018W=l30?ooo`030;md0000M;l0oooo00P0oooo00<0
00000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0
001o0?ooo`3oool06@3oool70?l005`0oooo00<000000?ooo`3oool03`3oool002/0oooo00<0okmd
0000M02oool00`3oool01P3ogi`0B01809cOo`3ogi`0B00007Boo`<0oooo00<0gia80000M02oool0
203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0
K`3oool00`0007l0oooo0?ooo`0K0?ooo`L0o`00FP3oool00`000000oooo0?ooo`0?0?ooo`00:`3o
ool00`3OW4P0001d0;ooo`030?ooo`060?oOW0180000M;oo0?oOW01804P0W=oo0`3oool00`3o_g@0
001d0;ooo`080?ooo`@00000o`0007n00000O`L0o`00E@0007l400000140oooo000[0?ooo`030=nL
B00004P0W=oo00<0oooo00H0okmd0000M02oool0okmd0000B02Lgol30?ooo`030?noM00004P0W=oo
00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo
06l0oooo00<0001o0?ooo`3oool07`3oool70?l005H0oooo00<000000?ooo`3oool03`3oool002/0
oooo00`0gia80000000007@0_ooo0?ooo`3ooml0W4P0001d_`3oool0okmd0000B02Lgol30?ooo`03
0?noM00004P0W=oo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?ooo`03
0000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool08@3oool70?l005@0oooo00<000000?ooo`3o
ool03`3oool002/0oooo00@0okmd0000M02ookl0M0000P0000001P18W=l0oooo0?ooo`3ogi`0B018
09cOo`<0oooo00<0okmd0000M02oool0203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0
oooo0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`0S0?ooo`P0o`00D@3oool0
0`000000oooo0?ooo`0?0?ooo`00:`3oool00`3ogi`0B01809cOo`060?ooo`030?oOW0180000M;oo
00<0oooo00<0gia80000M02oool0203oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo
0700oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`0U0?ooo`P0o`00C`3oool00`00
0000oooo0?ooo`0?0?ooo`00:`3oool00`3ooml0W4P004RLg`030?ooo`060=nLB00007@0_ooo0?oo
g`2LB000B9cO0`3oool00`2oM00007Bo0?ooo`080?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo02L0oooo203o001=
0?ooo`030000003oool0oooo00l0oooo000/0?ooo`070?noM000B9`0gooo0?ooo`3ookl0M000001d
_`020?ooo`070?noM00004P0W=oo0?ooo`3o_g@0001809cOo`090?ooo`030000003oool0oooo07/0
oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo02X0
oooo1`3o001;0?ooo`030000003oool0oooo00l0oooo000]0?ooo`050?oOW0180000000000000000
M;l0103oool01@3o_g@000000000000004P0W=oo00X0oooo00<000000?ooo`3oool0N`3oool00`00
07l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0;03oool70?l0
04T0oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0
oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0;P3oool80?l004H0
oooo00<000000?ooo`3oool03`3oool004D0oooo0`00001k0?ooo`030000O`3oool0oooo0700oooo
00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`0`0?ooo`P0o`00@P3oool300000140oooo
00150?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?oo
o`1_0?ooo`030000O`3oool0oooo0380oooo203o00120?ooo`030000003oool0oooo00l0oooo0015
0?ooo`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_
0?ooo`030000O`3oool0oooo03D0oooo1`3o00100?ooo`030000003oool0oooo00l0oooo00150?oo
o`030000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?oo
o`030000O`3oool0oooo03L0oooo1`3o000n0?ooo`030000003oool0oooo00l0oooo00150?ooo`03
0000003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`03
0000O`3oool0oooo03T0oooo1`3o000l0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000
003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo03/0oooo1`3o000j0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003o
ool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo03d0oooo1`3o000h0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0
oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo03l0oooo1`3o000f0?ooo`030000003oool0oooo00l0oooo00150?ooo`<00000N`3oool00`00
07l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0@@3oool70?l0
0380oooo0`00000A0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700
oooo00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`130?ooo`L0o`00<P3oool00`000000
oooo0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo
00<0001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`150?ooo`L0o`00<03oool00`000000oooo
0?ooo`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0
001o0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`170?ooo`L0o`00;P3oool00`000000oooo0?oo
o`0?0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o
0?ooo`3oool0K`3oool00`0007l0oooo0?ooo`190?ooo`L0o`00;03oool00`000000oooo0?ooo`0?
0?ooo`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?oo
o`3oool0K`3oool00`0007l0oooo0?ooo`1;0?ooo`L0o`00:P3oool00`000000oooo0?ooo`0?0?oo
o`00A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3o
ool0K`3oool00`0007l0oooo0?ooo`1=0?ooo`L0o`00:03oool00`000000oooo0?ooo`0?0?ooo`00
A@3oool00`000000oooo0?ooo`1k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3oool0
K`3oool00`0007l0oooo0?ooo`1?0?ooo`L0o`009P3oool00`000000oooo0?ooo`0?0?ooo`00A@3o
ool3000007/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo0540oooo1`3o000R0?ooo`<000004@3oool004D0oooo00<000000?ooo`3oool0N`3oool0
0`0007l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0D`3oool7
0?l00280oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`00
07l0oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0E@3oool70?l0
0200oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0
oooo0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0E`3oool70?l001h0
oooo00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo
0?ooo`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0F@3oool70?l001`0oooo
00<000000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0F`3oool70?l001X0oooo00<0
00000?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`
0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0G@3oool80?l001L0oooo00<00000
0?ooo`3oool03`3oool004D0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?oo
o`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0G`3oool80?l001D0oooo00<000000?oo
o`3oool03`3oool004D0oooo0`00001k0?ooo`030000O`3oool0oooo0700oooo00<0001o0?ooo`3o
ool0K`3oool00`0007l0oooo0?ooo`1Q0?ooo`P0o`004@3oool300000140oooo00150?ooo`030000
003oool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000
O`3oool0oooo06@0oooo1`3o000A0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003o
ool0oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3o
ool0oooo06H0oooo203o000>0?ooo`030000003oool0oooo00l0oooo00150?ooo`030000003oool0
oooo07/0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0
oooo06P0oooo203o000<0?ooo`030000003oool0oooo00l0oooo000]0?ooo`030=nLB00007@0_ooo
00H0oooo00D0gia8000000000000001809cOo`0:0?ooo`030000003oool0oooo07/0oooo00<0001o
0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`030000O`3oool0oooo06X0oooo203o000:
0?ooo`030000003oool0oooo00l0oooo000]0?ooo`030?noM00004P0W=oo00D0oooo00L0okmd0000
B02Lgol0oooo0?noM00004P0W=oo00T0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?oo
o`1`0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0K@3oool50?l000X0oooo00<0
00000?ooo`3oool03`3oool002d0oooo00<0omnL04P0001d_ol0103oool00`3ooml0W4P004RLg`03
0?ooo`030;md0000M;l0oooo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`
0?ooo`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0K`3oool30?l000X0oooo00<00000
0?ooo`3oool03`3oool002d0oooo00<0oono07@00018W=l0103oool00`3ogi`0B00007Boo`030?oo
o`030=nLB00007@0_ooo00P0oooo00<000000?ooo`3oool0N`3oool00`0007l0oooo0?ooo`1`0?oo
o`030000O`3oool0oooo06l0oooo00<0001o0?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?oo
o`00;P3oool00`2oM00004RL0=ooo`030?ooo`030?oOW01804P0W=oo00<0oooo00<0okmd0000M02o
ool0203oool4000007X0oooo00<0001o0?ooo`3oool0L03oool00`0007l0oooo0?ooo`1_0?ooo`03
0000O`3oool0oooo07T0oooo1000000A0?ooo`00;P3oool00`3o_g@0001809cOo`030?ooo`030?no
M00004P0W=oo00<0oooo00<0okmd0000B02Lgol0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`00;P3o
ool00`3ookl0M00004RLg`030?ooo`030?noM00004P0W=oo00<0oooo00<0okmd0000B02Lgol0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo000_0?ooo`030;md000007@0
_ooo0080oooo00<0omnL04P0B02Lgol00`3oool00`3o_g@0001d0;ooo`080?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03`3oool002l0oooo00<0omnL04P00018W=l00P3oool00`3o
gi`0B00007Boo`030?ooo`030=nLB00007@0_ooo00P0ooooo`00003T00000140oooo000`0?ooo`07
0=nLB00007@0_ooo0?ooo`3ooml0W4P004RLg`030?ooo`030;md0000M;l0oooo0?l0ooooo@3oool0
0300oooo00<0oono07@00000M;l00P3oool01`3o_g@0001809cOo`3oool0okmd0000B02Lgol0o`3o
ooon0?ooo`00:`3oool00`3o_g@00000000000050000000407Boo`3oool0oooo0?noM080000000<0
001809cOo`3oool0o`3oooon0?ooo`00o`3ooooo0?oooc/0oooo003o0?ooool0oooo>`3oool00?l0
ooooo`3ooolk0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 568.25}, {350.875, 0}} -> {-0.353116, -13.2002, \
0.00545119, 0.305311}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1920}, {0, 1113}},
WindowSize->{739, 937},
WindowMargins->{{Automatic, 390}, {-6, Automatic}},
Magnification->1.25
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 64, "Subtitle"],
Cell[1816, 55, 126, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[1967, 62, 31, 0, 48, "Subsection"],
Cell[2001, 64, 119, 2, 35, "Input"],
Cell[2123, 68, 377, 6, 98, "Input"],
Cell[2503, 76, 132, 2, 56, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2672, 83, 44, 0, 48, "Subsection"],
Cell[2719, 85, 341, 7, 164, "Text"],

Cell[CellGroupData[{
Cell[3085, 96, 229, 4, 58, "Input"],
Cell[3317, 102, 142, 2, 53, "Output"],
Cell[3462, 106, 151, 2, 65, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3662, 114, 32, 0, 48, "Subsection"],

Cell[CellGroupData[{
Cell[3719, 118, 214, 3, 56, "Input"],
Cell[3936, 123, 209, 3, 56, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4194, 132, 66, 0, 48, "Subsection"],
Cell[4263, 134, 45, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[4333, 138, 538, 8, 182, "Input"],
Cell[4874, 148, 89524, 1917, 362, 21784, 1076, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

